@@ -1,8 +1,8 @@
 package Net::Dropbear::SSHd;
 
 use strict;
-use v5.12;
-our $VERSION = '0.03';
+use v5.8;
+our $VERSION = '0.04';
 
 use Child;
 
@@ -108,7 +108,7 @@ sub run
   return;
 }
 
-sub kill
+sub stop
 {
   my $self = shift;
   if ($self->is_running)
@@ -457,7 +457,7 @@ handles between the processes.
 
 Returns true if Dropbear is running, false if it's not.
 
-=head2 kill
+=head2 stop
 
 This will stop Dropbear.
 
